==> shoppingMall-dao-6.0.1-sources.jar: com/viontech/mall/vobase/LogVoBase.java <==
package com.viontech.mall.vobase;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.viontech.keliu.base.VoInterface;
import com.viontech.mall.model.Log;
import com.viontech.mall.model.User;

import java.util.ArrayList;
import java.util.Date;

public class LogVoBase extends Log implements VoInterface<Log> {
    private Log log;

    @JsonIgnore
    private ArrayList<Long> id_arr;

    @JsonIgnore
    private Long id_gt;

    @JsonIgnore
    private Long id_lt;

    @JsonIgnore
    private Long id_gte;

    @JsonIgnore
    private Long id_lte;

    @JsonIgnore
    private Boolean businessName_null;

    @JsonIgnore
    private ArrayList<String> businessName_arr;

    @JsonIgnore
    private String businessName_like;

    @JsonIgnore
    private Boolean opType_null;

    @JsonIgnore
    private ArrayList<Short> opType_arr;

    @JsonIgnore
    private Short opType_gt;

    @JsonIgnore
    private Short opType_lt;

    @JsonIgnore
    private Short opType_gte;

    @JsonIgnore
    private Short opType_lte;

    @JsonIgnore
    private Boolean content_null;

    @JsonIgnore
    private ArrayList<String> content_arr;

    @JsonIgnore
    private String content_like;

    @JsonIgnore
    private Boolean opUsername_null;

    @JsonIgnore
    private ArrayList<String> opUsername_arr;

    @JsonIgnore
    private String opUsername_like;

    @JsonIgnore
    private Boolean opTime_null;

    @JsonIgnore
    private ArrayList<Date> opTime_arr;

    @JsonIgnore
    private Date opTime_gt;

    @JsonIgnore
    private Date opTime_lt;

    @JsonIgnore
    private Date opTime_gte;

    @JsonIgnore
    private Date opTime_lte;

    @JsonIgnore
    private Boolean tableName_null;

    @JsonIgnore
    private ArrayList<String> tableName_arr;

    @JsonIgnore
    private String tableName_like;

    @JsonIgnore
    private Boolean opUserId_null;

    @JsonIgnore
    private ArrayList<Long> opUserId_arr;

    @JsonIgnore
    private Long opUserId_gt;

    @JsonIgnore
    private Long opUserId_lt;

    @JsonIgnore
    private Long opUserId_gte;

    @JsonIgnore
    private Long opUserId_lte;

    @JsonIgnore
    private Boolean opLoginname_null;

    @JsonIgnore
    private ArrayList<String> opLoginname_arr;

    @JsonIgnore
    private String opLoginname_like;

    @JsonIgnore
    private Boolean opIp_null;

    @JsonIgnore
    private ArrayList<String> opIp_arr;

    @JsonIgnore
    private String opIp_like;

    public LogVoBase() {
        this(null);
    }

    public LogVoBase(Log log) {
        if(log == null) {
            log = new Log();
        }
        this.log = log;
    }

    @JsonIgnore
    public Log getModel() {
        return log;
    }

    public void setModel(Log log) {
        this.log = log;
    }

    public ArrayList<Long> getId_arr() {
        return id_arr;
    }

    public void setId_arr(ArrayList<Long> id_arr) {
        this.id_arr = id_arr;
    }

    public Long getId_gt() {
        return id_gt;
    }

    public void setId_gt(Long id_gt) {
        this.id_gt = id_gt;
    }

    public Long getId_lt() {
        return id_lt;
    }

    public void setId_lt(Long id_lt) {
        this.id_lt = id_lt;
    }

    public Long getId_gte() {
        return id_gte;
    }

    public void setId_gte(Long id_gte) {
        this.id_gte = id_gte;
    }

    public Long getId_lte() {
        return id_lte;
    }

    public void setId_lte(Long id_lte) {
        this.id_lte = id_lte;
    }

    public Long getId() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getId();
    }

    public void setId(Long id) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setId(id);
    }

    public Boolean getBusinessName_null() {
        return businessName_null;
    }

    public void setBusinessName_null(Boolean businessName_null) {
        this.businessName_null = businessName_null;
    }

    public ArrayList<String> getBusinessName_arr() {
        return businessName_arr;
    }

    public void setBusinessName_arr(ArrayList<String> businessName_arr) {
        this.businessName_arr = businessName_arr;
    }

    public String getBusinessName_like() {
        return businessName_like;
    }

    public void setBusinessName_like(String businessName_like) {
        this.businessName_like = businessName_like;
    }

    public String getBusinessName() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getBusinessName();
    }

    public void setBusinessName(String businessName) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setBusinessName(businessName);
    }

    public Boolean getOpType_null() {
        return opType_null;
    }

    public void setOpType_null(Boolean opType_null) {
        this.opType_null = opType_null;
    }

    public ArrayList<Short> getOpType_arr() {
        return opType_arr;
    }

    public void setOpType_arr(ArrayList<Short> opType_arr) {
        this.opType_arr = opType_arr;
    }

    public Short getOpType_gt() {
        return opType_gt;
    }

    public void setOpType_gt(Short opType_gt) {
        this.opType_gt = opType_gt;
    }

    public Short getOpType_lt() {
        return opType_lt;
    }

    public void setOpType_lt(Short opType_lt) {
        this.opType_lt = opType_lt;
    }

    public Short getOpType_gte() {
        return opType_gte;
    }

    public void setOpType_gte(Short opType_gte) {
        this.opType_gte = opType_gte;
    }

    public Short getOpType_lte() {
        return opType_lte;
    }

    public void setOpType_lte(Short opType_lte) {
        this.opType_lte = opType_lte;
    }

    public Short getOpType() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpType();
    }

    public void setOpType(Short opType) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpType(opType);
    }

    public Boolean getContent_null() {
        return content_null;
    }

    public void setContent_null(Boolean content_null) {
        this.content_null = content_null;
    }

    public ArrayList<String> getContent_arr() {
        return content_arr;
    }

    public void setContent_arr(ArrayList<String> content_arr) {
        this.content_arr = content_arr;
    }

    public String getContent_like() {
        return content_like;
    }

    public void setContent_like(String content_like) {
        this.content_like = content_like;
    }

    public String getContent() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getContent();
    }

    public void setContent(String content) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setContent(content);
    }

    public Boolean getOpUsername_null() {
        return opUsername_null;
    }

    public void setOpUsername_null(Boolean opUsername_null) {
        this.opUsername_null = opUsername_null;
    }

    public ArrayList<String> getOpUsername_arr() {
        return opUsername_arr;
    }

    public void setOpUsername_arr(ArrayList<String> opUsername_arr) {
        this.opUsername_arr = opUsername_arr;
    }

    public String getOpUsername_like() {
        return opUsername_like;
    }

    public void setOpUsername_like(String opUsername_like) {
        this.opUsername_like = opUsername_like;
    }

    public String getOpUsername() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpUsername();
    }

    public void setOpUsername(String opUsername) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpUsername(opUsername);
    }

    public Boolean getOpTime_null() {
        return opTime_null;
    }

    public void setOpTime_null(Boolean opTime_null) {
        this.opTime_null = opTime_null;
    }

    public ArrayList<Date> getOpTime_arr() {
        return opTime_arr;
    }

    public void setOpTime_arr(ArrayList<Date> opTime_arr) {
        this.opTime_arr = opTime_arr;
    }

    public Date getOpTime_gt() {
        return opTime_gt;
    }

    public void setOpTime_gt(Date opTime_gt) {
        this.opTime_gt = opTime_gt;
    }

    public Date getOpTime_lt() {
        return opTime_lt;
    }

    public void setOpTime_lt(Date opTime_lt) {
        this.opTime_lt = opTime_lt;
    }

    public Date getOpTime_gte() {
        return opTime_gte;
    }

    public void setOpTime_gte(Date opTime_gte) {
        this.opTime_gte = opTime_gte;
    }

    public Date getOpTime_lte() {
        return opTime_lte;
    }

    public void setOpTime_lte(Date opTime_lte) {
        this.opTime_lte = opTime_lte;
    }

    public Date getOpTime() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpTime();
    }

    public void setOpTime(Date opTime) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpTime(opTime);
    }

    public Boolean getTableName_null() {
        return tableName_null;
    }

    public void setTableName_null(Boolean tableName_null) {
        this.tableName_null = tableName_null;
    }

    public ArrayList<String> getTableName_arr() {
        return tableName_arr;
    }

    public void setTableName_arr(ArrayList<String> tableName_arr) {
        this.tableName_arr = tableName_arr;
    }

    public String getTableName_like() {
        return tableName_like;
    }

    public void setTableName_like(String tableName_like) {
        this.tableName_like = tableName_like;
    }

    public String getTableName() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getTableName();
    }

    public void setTableName(String tableName) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setTableName(tableName);
    }

    public Boolean getOpUserId_null() {
        return opUserId_null;
    }

    public void setOpUserId_null(Boolean opUserId_null) {
        this.opUserId_null = opUserId_null;
    }

    public ArrayList<Long> getOpUserId_arr() {
        return opUserId_arr;
    }

    public void setOpUserId_arr(ArrayList<Long> opUserId_arr) {
        this.opUserId_arr = opUserId_arr;
    }

    public Long getOpUserId_gt() {
        return opUserId_gt;
    }

    public void setOpUserId_gt(Long opUserId_gt) {
        this.opUserId_gt = opUserId_gt;
    }

    public Long getOpUserId_lt() {
        return opUserId_lt;
    }

    public void setOpUserId_lt(Long opUserId_lt) {
        this.opUserId_lt = opUserId_lt;
    }

    public Long getOpUserId_gte() {
        return opUserId_gte;
    }

    public void setOpUserId_gte(Long opUserId_gte) {
        this.opUserId_gte = opUserId_gte;
    }

    public Long getOpUserId_lte() {
        return opUserId_lte;
    }

    public void setOpUserId_lte(Long opUserId_lte) {
        this.opUserId_lte = opUserId_lte;
    }

    public Long getOpUserId() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpUserId();
    }

    public void setOpUserId(Long opUserId) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpUserId(opUserId);
    }

    public Boolean getOpLoginname_null() {
        return opLoginname_null;
    }

    public void setOpLoginname_null(Boolean opLoginname_null) {
        this.opLoginname_null = opLoginname_null;
    }

    public ArrayList<String> getOpLoginname_arr() {
        return opLoginname_arr;
    }

    public void setOpLoginname_arr(ArrayList<String> opLoginname_arr) {
        this.opLoginname_arr = opLoginname_arr;
    }

    public String getOpLoginname_like() {
        return opLoginname_like;
    }

    public void setOpLoginname_like(String opLoginname_like) {
        this.opLoginname_like = opLoginname_like;
    }

    public String getOpLoginname() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpLoginname();
    }

    public void setOpLoginname(String opLoginname) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpLoginname(opLoginname);
    }

    public Boolean getOpIp_null() {
        return opIp_null;
    }

    public void setOpIp_null(Boolean opIp_null) {
        this.opIp_null = opIp_null;
    }

    public ArrayList<String> getOpIp_arr() {
        return opIp_arr;
    }

    public void setOpIp_arr(ArrayList<String> opIp_arr) {
        this.opIp_arr = opIp_arr;
    }

    public String getOpIp_like() {
        return opIp_like;
    }

    public void setOpIp_like(String opIp_like) {
        this.opIp_like = opIp_like;
    }

    public String getOpIp() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpIp();
    }

    public void setOpIp(String opIp) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpIp(opIp);
    }

    public User getUser() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getUser();
    }

    public void setUser(User user) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setUser(user);
    }
}

==> shoppingMall-dao-6.0.5-sources.jar: com/viontech/mall/vobase/LogVoBase.java <==
package com.viontech.mall.vobase;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.viontech.keliu.base.VoInterface;
import com.viontech.mall.model.Account;
import com.viontech.mall.model.Log;
import com.viontech.mall.model.User;
import java.util.ArrayList;
import java.util.Date;

public class LogVoBase extends Log implements VoInterface<Log> {
    private Log log;

    @JsonIgnore
    private ArrayList<Long> id_arr;

    @JsonIgnore
    private Long id_gt;

    @JsonIgnore
    private Long id_lt;

    @JsonIgnore
    private Long id_gte;

    @JsonIgnore
    private Long id_lte;

    @JsonIgnore
    private Boolean businessName_null;

    @JsonIgnore
    private ArrayList<String> businessName_arr;

    @JsonIgnore
    private String businessName_like;

    @JsonIgnore
    private Boolean opType_null;

    @JsonIgnore
    private ArrayList<Short> opType_arr;

    @JsonIgnore
    private Short opType_gt;

    @JsonIgnore
    private Short opType_lt;

    @JsonIgnore
    private Short opType_gte;

    @JsonIgnore
    private Short opType_lte;

    @JsonIgnore
    private Boolean content_null;

    @JsonIgnore
    private ArrayList<String> content_arr;

    @JsonIgnore
    private String content_like;

    @JsonIgnore
    private Boolean opUsername_null;

    @JsonIgnore
    private ArrayList<String> opUsername_arr;

    @JsonIgnore
    private String opUsername_like;

    @JsonIgnore
    private Boolean opTime_null;

    @JsonIgnore
    private ArrayList<Date> opTime_arr;

    @JsonIgnore
    private Date opTime_gt;

    @JsonIgnore
    private Date opTime_lt;

    @JsonIgnore
    private Date opTime_gte;

    @JsonIgnore
    private Date opTime_lte;

    @JsonIgnore
    private Boolean tableName_null;

    @JsonIgnore
    private ArrayList<String> tableName_arr;

    @JsonIgnore
    private String tableName_like;

    @JsonIgnore
    private Boolean opUserId_null;

    @JsonIgnore
    private ArrayList<Long> opUserId_arr;

    @JsonIgnore
    private Long opUserId_gt;

    @JsonIgnore
    private Long opUserId_lt;

    @JsonIgnore
    private Long opUserId_gte;

    @JsonIgnore
    private Long opUserId_lte;

    @JsonIgnore
    private Boolean opLoginname_null;

    @JsonIgnore
    private ArrayList<String> opLoginname_arr;

    @JsonIgnore
    private String opLoginname_like;

    @JsonIgnore
    private Boolean opIp_null;

    @JsonIgnore
    private ArrayList<String> opIp_arr;

    @JsonIgnore
    private String opIp_like;

    @JsonIgnore
    private Boolean accountId_null;

    @JsonIgnore
    private ArrayList<Long> accountId_arr;

    @JsonIgnore
    private Long accountId_gt;

    @JsonIgnore
    private Long accountId_lt;

    @JsonIgnore
    private Long accountId_gte;

    @JsonIgnore
    private Long accountId_lte;

    @JsonIgnore
    private Boolean accountName_null;

    @JsonIgnore
    private ArrayList<String> accountName_arr;

    @JsonIgnore
    private String accountName_like;

    public LogVoBase() {
        this(null);
    }

    public LogVoBase(Log log) {
        if(log == null) {
            log = new Log();
        }
        this.log = log;
    }

    @JsonIgnore
    public Log getModel() {
        return log;
    }

    public void setModel(Log log) {
        this.log = log;
    }

    public ArrayList<Long> getId_arr() {
        return id_arr;
    }

    public void setId_arr(ArrayList<Long> id_arr) {
        this.id_arr = id_arr;
    }

    public Long getId_gt() {
        return id_gt;
    }

    public void setId_gt(Long id_gt) {
        this.id_gt = id_gt;
    }

    public Long getId_lt() {
        return id_lt;
    }

    public void setId_lt(Long id_lt) {
        this.id_lt = id_lt;
    }

    public Long getId_gte() {
        return id_gte;
    }

    public void setId_gte(Long id_gte) {
        this.id_gte = id_gte;
    }

    public Long getId_lte() {
        return id_lte;
    }

    public void setId_lte(Long id_lte) {
        this.id_lte = id_lte;
    }

    public Long getId() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getId();
    }

    public void setId(Long id) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setId(id);
    }

    public Boolean getBusinessName_null() {
        return businessName_null;
    }

    public void setBusinessName_null(Boolean businessName_null) {
        this.businessName_null = businessName_null;
    }

    public ArrayList<String> getBusinessName_arr() {
        return businessName_arr;
    }

    public void setBusinessName_arr(ArrayList<String> businessName_arr) {
        this.businessName_arr = businessName_arr;
    }

    public String getBusinessName_like() {
        return businessName_like;
    }

    public void setBusinessName_like(String businessName_like) {
        this.businessName_like = businessName_like;
    }

    public String getBusinessName() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getBusinessName();
    }

    public void setBusinessName(String businessName) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setBusinessName(businessName);
    }

    public Boolean getOpType_null() {
        return opType_null;
    }

    public void setOpType_null(Boolean opType_null) {
        this.opType_null = opType_null;
    }

    public ArrayList<Short> getOpType_arr() {
        return opType_arr;
    }

    public void setOpType_arr(ArrayList<Short> opType_arr) {
        this.opType_arr = opType_arr;
    }

    public Short getOpType_gt() {
        return opType_gt;
    }

    public void setOpType_gt(Short opType_gt) {
        this.opType_gt = opType_gt;
    }

    public Short getOpType_lt() {
        return opType_lt;
    }

    public void setOpType_lt(Short opType_lt) {
        this.opType_lt = opType_lt;
    }

    public Short getOpType_gte() {
        return opType_gte;
    }

    public void setOpType_gte(Short opType_gte) {
        this.opType_gte = opType_gte;
    }

    public Short getOpType_lte() {
        return opType_lte;
    }

    public void setOpType_lte(Short opType_lte) {
        this.opType_lte = opType_lte;
    }

    public Short getOpType() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpType();
    }

    public void setOpType(Short opType) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpType(opType);
    }

    public Boolean getContent_null() {
        return content_null;
    }

    public void setContent_null(Boolean content_null) {
        this.content_null = content_null;
    }

    public ArrayList<String> getContent_arr() {
        return content_arr;
    }

    public void setContent_arr(ArrayList<String> content_arr) {
        this.content_arr = content_arr;
    }

    public String getContent_like() {
        return content_like;
    }

    public void setContent_like(String content_like) {
        this.content_like = content_like;
    }

    public String getContent() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getContent();
    }

    public void setContent(String content) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setContent(content);
    }

    public Boolean getOpUsername_null() {
        return opUsername_null;
    }

    public void setOpUsername_null(Boolean opUsername_null) {
        this.opUsername_null = opUsername_null;
    }

    public ArrayList<String> getOpUsername_arr() {
        return opUsername_arr;
    }

    public void setOpUsername_arr(ArrayList<String> opUsername_arr) {
        this.opUsername_arr = opUsername_arr;
    }

    public String getOpUsername_like() {
        return opUsername_like;
    }

    public void setOpUsername_like(String opUsername_like) {
        this.opUsername_like = opUsername_like;
    }

    public String getOpUsername() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpUsername();
    }

    public void setOpUsername(String opUsername) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpUsername(opUsername);
    }

    public Boolean getOpTime_null() {
        return opTime_null;
    }

    public void setOpTime_null(Boolean opTime_null) {
        this.opTime_null = opTime_null;
    }

    public ArrayList<Date> getOpTime_arr() {
        return opTime_arr;
    }

    public void setOpTime_arr(ArrayList<Date> opTime_arr) {
        this.opTime_arr = opTime_arr;
    }

    public Date getOpTime_gt() {
        return opTime_gt;
    }

    public void setOpTime_gt(Date opTime_gt) {
        this.opTime_gt = opTime_gt;
    }

    public Date getOpTime_lt() {
        return opTime_lt;
    }

    public void setOpTime_lt(Date opTime_lt) {
        this.opTime_lt = opTime_lt;
    }

    public Date getOpTime_gte() {
        return opTime_gte;
    }

    public void setOpTime_gte(Date opTime_gte) {
        this.opTime_gte = opTime_gte;
    }

    public Date getOpTime_lte() {
        return opTime_lte;
    }

    public void setOpTime_lte(Date opTime_lte) {
        this.opTime_lte = opTime_lte;
    }

    public Date getOpTime() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpTime();
    }

    public void setOpTime(Date opTime) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpTime(opTime);
    }

    public Boolean getTableName_null() {
        return tableName_null;
    }

    public void setTableName_null(Boolean tableName_null) {
        this.tableName_null = tableName_null;
    }

    public ArrayList<String> getTableName_arr() {
        return tableName_arr;
    }

    public void setTableName_arr(ArrayList<String> tableName_arr) {
        this.tableName_arr = tableName_arr;
    }

    public String getTableName_like() {
        return tableName_like;
    }

    public void setTableName_like(String tableName_like) {
        this.tableName_like = tableName_like;
    }

    public String getTableName() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getTableName();
    }

    public void setTableName(String tableName) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setTableName(tableName);
    }

    public Boolean getOpUserId_null() {
        return opUserId_null;
    }

    public void setOpUserId_null(Boolean opUserId_null) {
        this.opUserId_null = opUserId_null;
    }

    public ArrayList<Long> getOpUserId_arr() {
        return opUserId_arr;
    }

    public void setOpUserId_arr(ArrayList<Long> opUserId_arr) {
        this.opUserId_arr = opUserId_arr;
    }

    public Long getOpUserId_gt() {
        return opUserId_gt;
    }

    public void setOpUserId_gt(Long opUserId_gt) {
        this.opUserId_gt = opUserId_gt;
    }

    public Long getOpUserId_lt() {
        return opUserId_lt;
    }

    public void setOpUserId_lt(Long opUserId_lt) {
        this.opUserId_lt = opUserId_lt;
    }

    public Long getOpUserId_gte() {
        return opUserId_gte;
    }

    public void setOpUserId_gte(Long opUserId_gte) {
        this.opUserId_gte = opUserId_gte;
    }

    public Long getOpUserId_lte() {
        return opUserId_lte;
    }

    public void setOpUserId_lte(Long opUserId_lte) {
        this.opUserId_lte = opUserId_lte;
    }

    public Long getOpUserId() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpUserId();
    }

    public void setOpUserId(Long opUserId) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpUserId(opUserId);
    }

    public Boolean getOpLoginname_null() {
        return opLoginname_null;
    }

    public void setOpLoginname_null(Boolean opLoginname_null) {
        this.opLoginname_null = opLoginname_null;
    }

    public ArrayList<String> getOpLoginname_arr() {
        return opLoginname_arr;
    }

    public void setOpLoginname_arr(ArrayList<String> opLoginname_arr) {
        this.opLoginname_arr = opLoginname_arr;
    }

    public String getOpLoginname_like() {
        return opLoginname_like;
    }

    public void setOpLoginname_like(String opLoginname_like) {
        this.opLoginname_like = opLoginname_like;
    }

    public String getOpLoginname() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpLoginname();
    }

    public void setOpLoginname(String opLoginname) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpLoginname(opLoginname);
    }

    public Boolean getOpIp_null() {
        return opIp_null;
    }

    public void setOpIp_null(Boolean opIp_null) {
        this.opIp_null = opIp_null;
    }

    public ArrayList<String> getOpIp_arr() {
        return opIp_arr;
    }

    public void setOpIp_arr(ArrayList<String> opIp_arr) {
        this.opIp_arr = opIp_arr;
    }

    public String getOpIp_like() {
        return opIp_like;
    }

    public void setOpIp_like(String opIp_like) {
        this.opIp_like = opIp_like;
    }

    public String getOpIp() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getOpIp();
    }

    public void setOpIp(String opIp) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setOpIp(opIp);
    }

    public Boolean getAccountId_null() {
        return accountId_null;
    }

    public void setAccountId_null(Boolean accountId_null) {
        this.accountId_null = accountId_null;
    }

    public ArrayList<Long> getAccountId_arr() {
        return accountId_arr;
    }

    public void setAccountId_arr(ArrayList<Long> accountId_arr) {
        this.accountId_arr = accountId_arr;
    }

    public Long getAccountId_gt() {
        return accountId_gt;
    }

    public void setAccountId_gt(Long accountId_gt) {
        this.accountId_gt = accountId_gt;
    }

    public Long getAccountId_lt() {
        return accountId_lt;
    }

    public void setAccountId_lt(Long accountId_lt) {
        this.accountId_lt = accountId_lt;
    }

    public Long getAccountId_gte() {
        return accountId_gte;
    }

    public void setAccountId_gte(Long accountId_gte) {
        this.accountId_gte = accountId_gte;
    }

    public Long getAccountId_lte() {
        return accountId_lte;
    }

    public void setAccountId_lte(Long accountId_lte) {
        this.accountId_lte = accountId_lte;
    }

    public Long getAccountId() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getAccountId();
    }

    public void setAccountId(Long accountId) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setAccountId(accountId);
    }

    public Boolean getAccountName_null() {
        return accountName_null;
    }

    public void setAccountName_null(Boolean accountName_null) {
        this.accountName_null = accountName_null;
    }

    public ArrayList<String> getAccountName_arr() {
        return accountName_arr;
    }

    public void setAccountName_arr(ArrayList<String> accountName_arr) {
        this.accountName_arr = accountName_arr;
    }

    public String getAccountName_like() {
        return accountName_like;
    }

    public void setAccountName_like(String accountName_like) {
        this.accountName_like = accountName_like;
    }

    public String getAccountName() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getAccountName();
    }

    public void setAccountName(String accountName) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setAccountName(accountName);
    }

    public User getUser() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getUser();
    }

    public void setUser(User user) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setUser(user);
    }

    public Account getAccount() {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        return this.getModel().getAccount();
    }

    public void setAccount(Account account) {
        if(getModel() == null ){
            throw new RuntimeException("model is null");
        }
        this.getModel().setAccount(account);
    }
}
